bayespy.inference.vmp.nodes.beta.BetaDistribution
=================================================

.. currentmodule:: bayespy.inference.vmp.nodes.beta

.. autoclass:: BetaDistribution

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~BetaDistribution.compute_cgf_from_parents
      ~BetaDistribution.compute_fixed_moments_and_f
      ~BetaDistribution.compute_gradient
      ~BetaDistribution.compute_logpdf
      ~BetaDistribution.compute_mask_to_parent
      ~BetaDistribution.compute_message_to_parent
      ~BetaDistribution.compute_moments_and_cgf
      ~BetaDistribution.compute_phi_from_parents
      ~BetaDistribution.plates_from_parent
      ~BetaDistribution.plates_to_parent
      ~BetaDistribution.random
   
   

   
   
   